pyjabber.webpage.api package
============================

Submodules
----------

pyjabber.webpage.api.api module
-------------------------------

.. automodule:: pyjabber.webpage.api.api
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyjabber.webpage.api
   :members:
   :undoc-members:
   :show-inheritance:
